#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COTH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COTH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/scalar/coth.hpp>

#endif
